@@ -563,9 +563,11 @@ class HastexoXBlock(XBlock,
         frag.add_javascript_url(
             self.runtime.local_resource_url(self, 'public/js/main.js')
         )
+        guac_js_version = settings.get("guacamole_js_version", "1.4.0")
         frag.add_javascript_url(
             self.runtime.local_resource_url(
-                self, 'public/js/guacamole-common-js/all.min.js')
+                self,
+                f'public/js/guacamole-common-js/{guac_js_version}-all.min.js')
         )
 
         # Create the stack in the database
